@@ -277,7 +277,7 @@ public class GeneralConfig extends SpecificConfig {
 	}
 
 	public boolean getUnAnchor() {
-		return Boolean.parseBoolean(getProperty("unAnchor", "false"));
+		return Boolean.parseBoolean(getProperty("unAnchor", "true"));
 	}
 	
 	public void setUnAnchor(boolean b) {
@@ -315,4 +315,16 @@ public class GeneralConfig extends SpecificConfig {
 	public void setTypeOfRandom(String type) {
 		setProperty("typeOfRandom", ""+type);
 	}
+
+	public boolean focusEqualsEdit() {
+		return Boolean.parseBoolean(getProperty("focusEqualsEdit", "true"));
+	}
+	public void setFocusEqualsEdit(boolean b) {
+		setProperty("focusEqualsEdit", ""+b);		
+	}
+
+	public boolean askWhenGraphIsNotSaved() {
+		return Boolean.parseBoolean(getProperty("askWhenGraphIsNotSaved", "false"));
+	}
+	
 }
